<?php
namespace Ep\Woo\Plugin\Account;

use Ep\Wp\Plugin\PluginInterface;
use WP_Error;
use Zend\Validator\ValidatorInterface;

/**
 * Dodaje ReCaptchu na registraciju korisnika.
 *
 * @package Ep\Woo\Plugin\Account
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class ReCaptcha  implements PluginInterface
{
    /** @var ValidatorInterface */
    protected $validator;

    /**
     * ReCaptcha constructor.
     *
     * @param ValidatorInterface $validator
     */
    public function __construct(ValidatorInterface $validator)
    {
        $this->validator = $validator;
    }

    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_filter('woocommerce_process_registration_errors', [$this, 'validateRegistration'], 10, 1);
    }

    /**
     * Nako što WooCommerce odvalidira svoje, mi još validiramo ReCaptchu.
     *
     * @param WP_Error $error
     *
     * @return WP_Error
     */
    public function wc_process_registration_errors(WP_Error $error)
    {
        if (!$this->validator->isValid($_POST['g-recaptcha-response'] ?? '')) {
            $error->add('recaptcha', implode("\n", $this->validator->getMessages()));
        }

        return $error;
    }
}